MSUM python toolbox — MSUMastro toolbox 0.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- MSUMastro toolbox 0.1 documentation »

# MSUM python toolbox

This set of tools is currently a mix of routines to fix up the headers of the FITS files generated at Feder Observatory and some more broadly useful code.

Contents:

- Installation
  - This software
  - Dependencies
- Header patching and other Feder-specific code
  - Overview
  - Details
- A tool for managing a set of images

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- modules |
- next |
- MSUMastro toolbox 0.1 documentation »